def setup(bot):
    bot.load_extension('Daug.extensions.channels')
    bot.load_extension('Daug.extensions.favorite')
    bot.load_extension('Daug.extensions.join')
    bot.load_extension('Daug.extensions.leave')
    bot.load_extension('Daug.extensions.thread')
    bot.load_extension('Daug.extensions.utils')
